==> typescript-node-scripts-0.1.10.tgz: package/scripts/initApp.js <==
process.on('unhandledRejection', err => {
    throw err
})

const fs = require('fs-extra')
const spawn = require('child_process').spawnSync
const exec = require('child_process').execSync
const path = require('path')
const os = require('os')
const chalk = require('chalk')
const projectJson = require('../package.json')

const argv = process.argv.slice(2)

const createApp = appName => {
    const appPath = path.join(process.cwd(), appName)

    console.log('Creating application ' + chalk.cyan(appName) + '\n')
    const appPackageJson = {
        name: appName,
        version: '0.1.0',
        main: 'src/index.ts',
        private: true,
        scripts: {
            test: 'typescript-node-scripts test',
            start: 'typescript-node-scripts start',
            build: 'typescript-node-scripts build',
        },
    }

    const packageDependencies = [...Object.keys(projectJson.peerDependencies), 'typescript-node-scripts']
    const packageDevDependencies = ['@types/node']

    // set up the template
    try {
        fs.statSync(appPath)
        console.log()
        console.log(chalk.red('Failed to create app.'))
        console.log(chalk.red('Directory "' + appName + '" exists.'))
        console.log()
        process.exit(1)
    } catch (_) {}
    fs.copySync(path.join(__dirname, '../template'), appPath)

    // create the package json
    fs.writeFileSync(path.join(appPath, 'package.json'), JSON.stringify(appPackageJson, null, 2) + os.EOL)
    // copy gitignore
    fs.copySync(path.join(__dirname, '../template/gitignore'), path.join(appPath, '.gitignore'))
    fs.unlinkSync(path.join(appPath, 'gitignore'))

    // install package dependencies
    console.log('Installing ' + [...packageDependencies, ...packageDevDependencies].map(i => chalk.cyan(i)).join(', '))
    spawn('yarnpkg', ['add', ...packageDependencies, '--silent'], {
        cwd: appPath,
        stdio: 'inherit',
    })
    spawn('yarnpkg', ['add', ...packageDevDependencies, '--dev', '--silent'], {
        cwd: appPath,
        stdio: 'inherit',
    })

    // initialize git repo
    try {
        exec('git init', {
            cwd: appPath,
            stdio: 'ignore',
        })
        exec('git add -A', {
            cwd: appPath,
            stdio: 'ignore',
        })
        exec('git commit -m "first commit by typescript-node-scripts"', {
            cwd: appPath,
            stdio: 'ignore',
        })
    } catch (e) {
        console.error(chalk.yellow('Failed to initialize git repository. You might want to initialize it yourself.'))
    }

    console.log()
    console.log(chalk.green('Successfully created ' + appName + ' at ' + appPath))
    console.log('Inside your project directory, you can run these commands:')
    console.log()
    console.log(chalk.cyan('  yarn start'))
    console.log('    Starts the development server.')
    console.log()
    console.log(chalk.cyan('  yarn test'))
    console.log('    Runs the Jest test runner.')
    console.log()
    console.log(chalk.cyan('  yarn build'))
    console.log('    Bundles your application into a production-ready bundle.')
    console.log()
    console.log(chalk.green('To get started right away, we recommend running: \n'))
    console.log(chalk.cyan('  cd'), appName)
    console.log(chalk.cyan('  yarn'), 'start')
    console.log()
}

createApp(argv[0])

==> typescript-node-scripts-0.1.11.tgz: package/scripts/initApp.js <==
process.on('unhandledRejection', err => {
    throw err
})

const fs = require('fs-extra')
const spawn = require('child_process').spawnSync
const exec = require('child_process').execSync
const path = require('path')
const os = require('os')
const chalk = require('chalk')
const projectJson = require('../package.json')

const argv = process.argv.slice(2)

const createApp = appName => {
    const appPath = path.join(process.cwd(), appName)

    console.log('Creating application ' + chalk.cyan(appName) + '\n')
    const appPackageJson = {
        name: appName,
        version: '0.1.0',
        main: 'src/index.ts',
        private: true,
        scripts: {
            test: 'typescript-node-scripts test',
            start: 'typescript-node-scripts start',
            build: 'typescript-node-scripts build',
            lint: 'tslint --project .',
        },
    }

    const packageDependencies = [...Object.keys(projectJson.peerDependencies), 'typescript-node-scripts']
    const packageDevDependencies = ['tslint', '@types/node']

    // set up the template
    try {
        fs.statSync(appPath)
        console.log()
        console.log(chalk.red('Failed to create app.'))
        console.log(chalk.red('Directory "' + appName + '" exists.'))
        console.log()
        process.exit(1)
    } catch (_) {}
    fs.copySync(path.join(__dirname, '../template'), appPath)

    // create the package json
    fs.writeFileSync(path.join(appPath, 'package.json'), JSON.stringify(appPackageJson, null, 2) + os.EOL)
    // copy gitignore
    fs.copySync(path.join(__dirname, '../template/gitignore'), path.join(appPath, '.gitignore'))
    fs.unlinkSync(path.join(appPath, 'gitignore'))

    // install package dependencies
    console.log('Installing ' + [...packageDependencies, ...packageDevDependencies].map(i => chalk.cyan(i)).join(', '))
    spawn('yarnpkg', ['add', ...packageDependencies, '--silent'], {
        cwd: appPath,
        stdio: 'inherit',
    })
    spawn('yarnpkg', ['add', ...packageDevDependencies, '--dev', '--silent'], {
        cwd: appPath,
        stdio: 'inherit',
    })

    // initialize git repo
    try {
        exec('git init', {
            cwd: appPath,
            stdio: 'ignore',
        })
        exec('git add -A', {
            cwd: appPath,
            stdio: 'ignore',
        })
        exec('git commit -m "first commit by typescript-node-scripts"', {
            cwd: appPath,
            stdio: 'ignore',
        })
    } catch (e) {
        console.error(chalk.yellow('Failed to initialize git repository. You might want to initialize it yourself.'))
    }

    console.log()
    console.log(chalk.green('Successfully created ' + appName + ' at ' + appPath))
    console.log('Inside your project directory, you can run these commands:')
    console.log()
    console.log(chalk.cyan('  yarn start'))
    console.log('    Starts the development server.')
    console.log()
    console.log(chalk.cyan('  yarn test'))
    console.log('    Runs the Jest test runner.')
    console.log()
    console.log(chalk.cyan('  yarn build'))
    console.log('    Bundles your application into a production-ready bundle.')
    console.log()
    console.log(chalk.green('To get started right away, we recommend running: \n'))
    console.log(chalk.cyan('  cd'), appName)
    console.log(chalk.cyan('  yarn'), 'start')
    console.log()
}

createApp(argv[0])
